mafw.examples.db\_processors
============================

.. automodule:: mafw.examples.db_processors

   
   .. rubric:: Classes

   .. autosummary::
   
      CountStandardTables
      File
      FillFileTableProcessor
   
   .. rubric:: Exceptions

   .. autosummary::
   
      FileDoesNotExist
   